@@ -33,7 +33,7 @@ impl TokenIdentifier {
 
 	#[inline]
 	pub fn is_egld(&self) -> bool {
-		self.0.is_empty()
+		self.is_empty()
 	}
 
 	#[inline]
@@ -41,6 +41,16 @@ impl TokenIdentifier {
 		!self.is_egld()
 	}
 
+	#[inline]
+	pub fn len(&self) -> usize {
+		self.0.len()
+	}
+
+	#[inline]
+	pub fn is_empty(&self) -> bool {
+		self.0.is_empty()
+	}
+
 	#[inline]
 	pub fn into_boxed_bytes(self) -> BoxedBytes {
 		self.0
@@ -59,6 +69,11 @@ impl TokenIdentifier {
 		self.0.as_slice()
 	}
 
+	#[inline]
+	pub fn as_ptr(&self) -> *const u8 {
+		self.0.as_ptr()
+	}
+
 	#[inline]
 	pub fn as_name(&self) -> &[u8] {
 		if self.is_egld() {
